---
name: Bug report
about: Create a report to help us fix the issue
title: '[BUG]'
labels: ''
assignees: matteosox

---

## Describe the bug 🐛 
A clear and concise description of what the bug is, i.e. what you did, what you expected to happen, and what happened instead.

## To Reproduce 🔁
Preferably a code snippet.

## Environment 🏔
Copy and paste what you get when you run the code below in the Python interpreter you're using:
`import sys, platform; print(f"{sys.version}\n{platform.platform()}")`

## Additional context ✨
Add any other context about the problem here.
